pub(crate) struct AudioPlayerMessage {
pub(crate) message: MediaMessage,
pub(crate) session: WeakRef<Session>,
pub(crate) cache_key: MessageCacheKey,
}Expand description
The data required to play an audio message.
Fields
message: MediaMessageThe audio message.
session: WeakRef<Session>The session that will be used to load the file.
cache_key: MessageCacheKeyThe cache key for the audio message.
The audio is only reloaded if the cache key changes. This is to avoid reloading the audio when the local echo is updated to a remote echo.
Implementations
Sourceimpl AudioPlayerMessage
impl AudioPlayerMessage
Sourcepub(crate) fn new(
message: MediaMessage,
session: &Session,
cache_key: MessageCacheKey,
) -> Self
pub(crate) fn new( message: MediaMessage, session: &Session, cache_key: MessageCacheKey, ) -> Self
Construct a new AudioPlayerMessage.